==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceSubresourcesBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesBuilder>{
  public CustomResourceSubresourcesBuilder() {
    this(false);
  }
  public CustomResourceSubresourcesBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceSubresources(), validationEnabled);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceSubresources(), validationEnabled);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance) {
    this(fluent, instance, false);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withScale(instance.getScale()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance) {
    this(instance,false);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withScale(instance.getScale()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources build() {
    CustomResourceSubresources buildable = new CustomResourceSubresources(fluent.getScale(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourcesBuilder that = (CustomResourceSubresourcesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceSubresourcesBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesBuilder>{
  public CustomResourceSubresourcesBuilder() {
    this(false);
  }
  public CustomResourceSubresourcesBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceSubresources(), validationEnabled);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceSubresources(), validationEnabled);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance) {
    this(fluent, instance, false);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withScale(instance.getScale()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance) {
    this(instance,false);
  }
  public CustomResourceSubresourcesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withScale(instance.getScale()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourcesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresources build() {
    CustomResourceSubresources buildable = new CustomResourceSubresources(fluent.getScale(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourcesBuilder that = (CustomResourceSubresourcesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
